@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.request.requestParams import RequestParams
 from nerualpha.services.jwt.jwtPayload import JWTPayload
 from nerualpha.providers.logger.ILogAction import ILogAction
+from nerualpha.request.IRequestParams import IRequestParams
 
 
 #interface
@@ -37,6 +37,9 @@ class IBridge(ABC):
     def runBackgroundTask(self,task):
         pass
     @abstractmethod
+    def createReadStream(self,path):
+        pass
+    @abstractmethod
     def toISOString(self,seconds):
         pass
     @abstractmethod
