@@ -58,10 +58,13 @@ class Neru(INeru):
         
         return self.getSessionById(id)
     
+    def getGlobalSession(self):
+        uuid = "00000000-0000-0000-0000-000000000000"
+        return self.getSessionById(uuid)
+    
     def getGlobalState(self):
-        id = f'application:{self.config.applicationId}'
-        session = self.createSessionWithId(id)
-        return State(session,f'application:{self.config.instanceServiceName}')
+        session = self.getGlobalSession()
+        return State(session,f'application:{self.config.instanceId}')
     
     def reprJSON(self):
         dict = {}
