@@ -32,8 +32,7 @@ class EventEmitter(IEventEmitter):
         self.url = self.config.getExecutionUrl(self.provider)
     
     async def emitSessionCreatedEvent(self,ttl):
-        secondsInTotal = self.bridge.getSystemTime() + ttl
-        expiresAt = self.bridge.toISOString(secondsInTotal)
+        expiresAt = self.bridge.toISOString(ttl)
         details = SessionCreatedDetails(expiresAt)
         event = self.eventFactory.createEvent(NeruEventTypes.SESSION_CREATED,details)
         await self.emit(event)
