@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.logger.ILogContext import ILogContext
+from nerualpha.providers.logger.ILogContext import ILogContext
 
 
 #interface
