@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IPayloadWithCallback import IPayloadWithCallback
-from src.providers.messages.contracts.IMessageContact import IMessageContact
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
+from nerualpha.providers.messages.contracts.IMessageContact import IMessageContact
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 
 #interface
