@@ -3,9 +3,9 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.providers.messages.contracts.IBaseMessage import IBaseMessage
-from nerualpha.providers.messages.contracts.IImagePayload import IImagePayload
+from nerualpha.providers.messages.contracts.IURLPayload import IURLPayload
 
 
 #interface
 class IMMSVCardMessage(IBaseMessage):
-    vcard:IImagePayload
+    vcard:IURLPayload
