@@ -2,14 +2,14 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.providers.messages.contracts.IImagePayload import IImagePayload
+from nerualpha.providers.messages.contracts.IURLPayload import IURLPayload
 from nerualpha.providers.messages.contracts.IMMSImageMessage import IMMSImageMessage
 
 @dataclass
 class MMSImageMessage(IMMSImageMessage):
     to: str
     from_: str
-    image: IImagePayload
+    image: IURLPayload
     channel: str = field(default = "mms")
     message_type: str = field(default = "image")
     def __init__(self):
