@@ -2,16 +2,16 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.providers.messages.contracts.IImagePayload import IImagePayload
+from nerualpha.providers.messages.contracts.IURLPayload import IURLPayload
 from nerualpha.providers.messages.contracts.IMMSVCardMessage import IMMSVCardMessage
 
 @dataclass
 class MMSVCardMessage(IMMSVCardMessage):
     to: str
-    message_type: str
     from_: str
-    channel: str
-    vcard: IImagePayload
+    vcard: IURLPayload
+    channel: str = field(default = "mms")
+    message_type: str = field(default = "vcard")
     def __init__(self):
         pass
     def reprJSON(self):
