@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.messages.contracts.IImageData import IImageData
-from src.providers.messages.contracts.ISendImageContent import ISendImageContent
+from nerualpha.providers.messages.contracts.IImageData import IImageData
+from nerualpha.providers.messages.contracts.ISendImageContent import ISendImageContent
 
 @dataclass
 class SendImageContent(ISendImageContent):
