@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.messages.contracts.ISendTextContent import ISendTextContent
+from nerualpha.providers.messages.contracts.ISendTextContent import ISendTextContent
 
 @dataclass
 class SendTextContent(ISendTextContent):
