@@ -7,10 +7,10 @@ from nerualpha.providers.messages.contracts.ISMSMessage import ISMSMessage
 @dataclass
 class SMSMessage(ISMSMessage):
     to: str
-    message_type: str
     from_: str
-    channel: str
     text: str
+    channel: str = field(default = "sms")
+    message_type: str = field(default = "text")
     def __init__(self):
         pass
     def reprJSON(self):
