@@ -2,16 +2,16 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.providers.messages.contracts.IImagePayload import IImagePayload
+from nerualpha.providers.messages.contracts.IURLPayload import IURLPayload
 from nerualpha.providers.messages.contracts.IWhatsappImageMessage import IWhatsappImageMessage
 
 @dataclass
 class WhatsappImageMessage(IWhatsappImageMessage):
     to: str
-    message_type: str
     from_: str
-    channel: str
-    image: IImagePayload
+    image: IURLPayload
+    channel: str = field(default = "whatsapp")
+    message_type: str = field(default = "image")
     def __init__(self):
         pass
     def reprJSON(self):
