@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.scheduler.contracts.IIntervalParams import IIntervalParams
+from nerualpha.providers.scheduler.contracts.IIntervalParams import IIntervalParams
 
 T = TypeVar("T")
 
