@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.scheduler.contracts.IIntervalParams import IIntervalParams
-from src.session.IPayloadWithCallback import IPayloadWithCallback
+from nerualpha.providers.scheduler.contracts.IIntervalParams import IIntervalParams
+from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
 
 T = TypeVar("T")
 
