@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.scheduler.contracts.IIntervalParams import IIntervalParams
-from src.providers.scheduler.contracts.IUntilParams import IUntilParams
+from nerualpha.providers.scheduler.contracts.IIntervalParams import IIntervalParams
+from nerualpha.providers.scheduler.contracts.IUntilParams import IUntilParams
 
 @dataclass
 class IntervalParams(IIntervalParams):
