@@ -4,5 +4,7 @@ from abc import ABC, abstractmethod
 
 
 class SchedulerActions:
-    create = "create"
+    Create = "create"
     Cancel = "cancel"
+    List = "list"
+    Get = "get"
