@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.state.IStateCommand import IStateCommand
-from src.providers.state.stateCommand import StateCommand
+from nerualpha.providers.state.IStateCommand import IStateCommand
+from nerualpha.providers.state.stateCommand import StateCommand
 
 
 #interface
