@@ -9,13 +9,15 @@ from nerualpha.providers.state.IState import IState
 from nerualpha.providers.state.IStateCommand import IStateCommand
 from nerualpha.providers.state.stateCommand import StateCommand
 from nerualpha.providers.state.stateOperations import StateOperations
+from nerualpha.request.requestMethods import RequestMethods
+from nerualpha.services.config.urlObject import UrlObject
 
 @dataclass
 class State(IState):
     commandService: ICommandService
     session: ISession
     bridge: IBridge
-    url: str
+    url: UrlObject
     namespace: str
     provider: str = field(default = "client-persistence-api")
     def __init__(self,session,namespace = None):
@@ -34,7 +36,7 @@ class State(IState):
         return StateCommand(op,self.namespace,key,args)
     
     async def executeCommand(self,command):
-        return await self.commandService.executeCommand(self.url,command,self.session.constructRequestHeaders())
+        return await self.commandService.executeCommand(self.url,RequestMethods.POST,command,self.session.constructRequestHeaders())
     
     async def set(self,key,value):
         payload = []
@@ -68,7 +70,7 @@ class State(IState):
         command = self.createCommand(StateOperations.HGETALL,htable,payload)
         response = await self.executeCommand(command)
         result = {}
-        for i in range(0,response.count,2):
+        for i in range(0,response.__len__(),2):
             result[response[i]] = response[i + 1]
         
         return result
@@ -77,7 +79,7 @@ class State(IState):
         command = self.createCommand(StateOperations.HMGET,htable,keys)
         response = await self.executeCommand(command)
         result = []
-        for i in range(0,response.count):
+        for i in range(0,response.__len__()):
             result.append(response[i])
         
         return result
@@ -87,7 +89,7 @@ class State(IState):
         command = self.createCommand(StateOperations.HVALS,htable,payload)
         response = await self.executeCommand(command)
         result = []
-        for i in range(0,response.count):
+        for i in range(0,response.__len__()):
             result.append(response[i])
         
         return result
@@ -101,7 +103,7 @@ class State(IState):
     async def hset(self,htable,keyValuePairs):
         payload = []
         keys = self.bridge.getObjectKeys(keyValuePairs)
-        for i in range(0,keys.count):
+        for i in range(0,keys.__len__()):
             payload.append(keys[i])
             payload.append(keyValuePairs[keys[i]])
         
@@ -128,7 +130,7 @@ class State(IState):
         command = self.createCommand(StateOperations.LRANGE,list,args)
         response = await self.executeCommand(command)
         result = []
-        for i in range(0,response.count):
+        for i in range(0,response.__len__()):
             result.append(self.bridge.jsonParse(response[i]))
         
         return result
