@@ -8,8 +8,8 @@ from nerualpha.providers.vonageAPI.contracts.invokePayload import InvokePayload
 from nerualpha.providers.voice.contracts.vapiCreateCallPayload import VapiCreateCallPayload
 from nerualpha.providers.voice.conversation import Conversation
 from nerualpha.providers.voice.contracts.IVapiEventParams import IVapiEventParams
-from nerualpha.providers.voice.contracts.IPhoneContact import IPhoneContact
 from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
+from nerualpha.providers.voice.contracts.vapiCreateCallResponse import VapiCreateCallResponse
 
 
 #interface
