@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IPayloadWithCallback import IPayloadWithCallback
-from src.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
+from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
+from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 
 
 #interface
