@@ -8,3 +8,6 @@ from abc import ABC, abstractmethod
 class IUser(ABC):
     id:str
     name:str
+    display_name:str
+    image_url:str
+    custom_data:object
