@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IAcceptInboundCallBody import IAcceptInboundCallBody
-from src.providers.voice.contracts.IChannel import IChannel
-from src.providers.voice.contracts.IUser import IUser
+from nerualpha.providers.voice.contracts.IAcceptInboundCallBody import IAcceptInboundCallBody
+from nerualpha.providers.voice.contracts.IChannel import IChannel
+from nerualpha.providers.voice.contracts.IUser import IUser
 
 @dataclass
 class AcceptInboundCallBody(IAcceptInboundCallBody):
