@@ -2,12 +2,17 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.providers.voice.contracts.IAddUserResponse import IAddUserResponse
+from nerualpha.providers.voice.contracts.selfLink import SelfLink
+from nerualpha.providers.voice.contracts.responseProperties import ResponseProperties
 
 @dataclass
-class AddUserResponse(IAddUserResponse):
-    display_name: str
-    name: str
+class AddUserResponse:
+    channels: object
+    _links: SelfLink
+    id: str
+    name: str = None
+    display_name: str = None
+    properties: ResponseProperties = None
     def __init__(self):
         pass
     def reprJSON(self):
