@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IChannelEndpoint import IChannelEndpoint
-from src.providers.voice.csChannelTypes import CSChannelTypes
+from nerualpha.providers.voice.contracts.IChannelEndpoint import IChannelEndpoint
+from nerualpha.providers.voice.csChannelTypes import CSChannelTypes
 
 @dataclass
 class ChannelAppEndpoint(IChannelEndpoint):
