@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IDeleteMemberPayload import IDeleteMemberPayload
-from src.providers.voice.contracts.IReason import IReason
-from src.providers.voice.memberStates import MemberStates
+from nerualpha.providers.voice.contracts.IDeleteMemberPayload import IDeleteMemberPayload
+from nerualpha.providers.voice.contracts.IReason import IReason
+from nerualpha.providers.voice.memberStates import MemberStates
 
 @dataclass
 class DeleteMemberPayload(IDeleteMemberPayload):
