@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IMedia import IMedia
-from src.providers.voice.contracts.IAudioSettings import IAudioSettings
+from nerualpha.providers.voice.contracts.IMedia import IMedia
+from nerualpha.providers.voice.contracts.IAudioSettings import IAudioSettings
 
 @dataclass
 class Media(IMedia):
