@@ -2,10 +2,10 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IPlayStopPayload import IPlayStopPayload
-from src.providers.voice.csEvents import CSEvents
-from src.providers.voice.contracts.IPlayStopBody import IPlayStopBody
-from src.providers.voice.contracts.playStopBody import PlayStopBody
+from nerualpha.providers.voice.contracts.IPlayStopPayload import IPlayStopPayload
+from nerualpha.providers.voice.csEvents import CSEvents
+from nerualpha.providers.voice.contracts.IPlayStopBody import IPlayStopBody
+from nerualpha.providers.voice.contracts.playStopBody import PlayStopBody
 
 @dataclass
 class PlayStopPayload(IPlayStopPayload):
