@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IPlayStreamPayload import IPlayStreamPayload
-from src.providers.voice.csEvents import CSEvents
-from src.providers.voice.contracts.IPlayStreamBody import IPlayStreamBody
+from nerualpha.providers.voice.contracts.IPlayStreamPayload import IPlayStreamPayload
+from nerualpha.providers.voice.csEvents import CSEvents
+from nerualpha.providers.voice.contracts.IPlayStreamBody import IPlayStreamBody
 
 @dataclass
 class PlayStreamPayload(IPlayStreamPayload):
