@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.ISayStopBody import ISayStopBody
+from nerualpha.providers.voice.contracts.ISayStopBody import ISayStopBody
 
 @dataclass
 class SayStopBody(ISayStopBody):
