@@ -2,10 +2,10 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.ISayStopPayload import ISayStopPayload
-from src.providers.voice.csEvents import CSEvents
-from src.providers.voice.contracts.ISayStopBody import ISayStopBody
-from src.providers.voice.contracts.sayStopBody import SayStopBody
+from nerualpha.providers.voice.contracts.ISayStopPayload import ISayStopPayload
+from nerualpha.providers.voice.csEvents import CSEvents
+from nerualpha.providers.voice.contracts.ISayStopBody import ISayStopBody
+from nerualpha.providers.voice.contracts.sayStopBody import SayStopBody
 
 @dataclass
 class SayStopPayload(ISayStopPayload):
