@@ -10,9 +10,13 @@ from nerualpha.providers.voice.contracts.ISayTextBody import ISayTextBody
 class SayTextPayload(ISayTextPayload):
     body: ISayTextBody
     type_: str
-    def __init__(self,body):
+    to: str = None
+    def __init__(self,body,to = None):
         self.type_ = CSEvents.AudioSay
         self.body = body
+        if to is not None:
+            self.to = to
+        
     
     def reprJSON(self):
         dict = {}
