@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IVapiEventParams import IVapiEventParams
+from nerualpha.providers.voice.contracts.IVapiEventParams import IVapiEventParams
 
 @dataclass
 class VapiEventParams(IVapiEventParams):
