@@ -14,7 +14,6 @@ from nerualpha.session.requestInterfaceForCallbacks import RequestInterfaceForCa
 from nerualpha.session.ISession import ISession
 from nerualpha.providers.vonageAPI.IVonageAPI import IVonageAPI
 from nerualpha.providers.voice.contracts.IVapiEventParams import IVapiEventParams
-from nerualpha.providers.voice.contracts.IPhoneContact import IPhoneContact
 from nerualpha.providers.voice.contracts.createConversationPayload import CreateConversationPayload
 from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 from nerualpha.providers.voice.contracts.vapiAnswerCallBack import VapiAnswerCallBack
@@ -23,6 +22,7 @@ from nerualpha.providers.voice.contracts.vapiCreateCallPayload import VapiCreate
 from nerualpha.providers.voice.contracts.onInboundCallPayload import OnInboundCallPayload
 from nerualpha.IBridge import IBridge
 from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
+from nerualpha.providers.voice.contracts.vapiCreateCallResponse import VapiCreateCallResponse
 
 @dataclass
 class Voice(IVoice):
@@ -40,6 +40,12 @@ class Voice(IVoice):
         
     
     def onInboundCall(self,callback,to,from_ = None):
+        if to.type_ is None:
+            to.type_ = "phone"
+        
+        if from_ is not None and from_.type_ is None:
+            from_.type_ = "phone"
+        
         payload = OnInboundCallPayload(self.session.wrapCallback(callback,[]),to,from_)
         action = ActionPayload(self.provider,VoiceActions.ConversationSubscribeInboundCall,payload)
         return RequestInterfaceForCallbacks(self.session,action)
