@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.vonageAI.contracts.IImportPayload import IImportPayload
+from nerualpha.providers.vonageAI.contracts.IImportPayload import IImportPayload
 
 @dataclass
 class ImportPayload(IImportPayload):
