@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.vonageAI.contracts.IVonageAiAnalyzePayload import IVonageAiAnalyzePayload
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.vonageAI.contracts.IVonageAiAnalyzePayload import IVonageAiAnalyzePayload
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 @dataclass
 class VonageAiAnalyzePayload(IVonageAiAnalyzePayload):
