@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.vonageAI.contracts.IVonageAiImportModelPayload import IVonageAiImportModelPayload
-from src.session.IWrappedCallback import IWrappedCallback
-from src.providers.vonageAI.contracts.IImportPayload import IImportPayload
+from nerualpha.providers.vonageAI.contracts.IVonageAiImportModelPayload import IVonageAiImportModelPayload
+from nerualpha.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.vonageAI.contracts.IImportPayload import IImportPayload
 
 @dataclass
 class VonageAiImportModelPayload(IVonageAiImportModelPayload):
