@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.requestInterface import RequestInterface
-from src.providers.vonageAPI.contracts.invokePayload import InvokePayload
+from nerualpha.session.requestInterface import RequestInterface
+from nerualpha.providers.vonageAPI.contracts.invokePayload import InvokePayload
 
 
 #interface
