@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.request.IRequestHeaders import IRequestHeaders
+from nerualpha.services.config.urlObject import UrlObject
 
 T = TypeVar("T")
 
@@ -10,6 +10,6 @@ T = TypeVar("T")
 #interface
 class IRequestParams(ABC,Generic[T]):
     method:str
-    url:str
+    url:UrlObject
     data:T
-    headers:IRequestHeaders
+    headers:Dict[str,str]
