@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.request.IRequest import IRequest
+from nerualpha.request.IRequest import IRequest
 
 @dataclass
 class Request(IRequest):
