@@ -2,17 +2,17 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.request.IRequestHeaders import IRequestHeaders
 from nerualpha.request.IRequestParams import IRequestParams
+from nerualpha.services.config.urlObject import UrlObject
 
 T = TypeVar("T")
 
 @dataclass
 class RequestParams(IRequestParams,Generic[T]):
-    url: str
+    url: UrlObject
     method: str
     data: T = None
-    headers: IRequestHeaders = None
+    headers: Dict[str,str] = None
     def __init__(self):
         pass
     def reprJSON(self):
