@@ -3,10 +3,9 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.IBridge import IBridge
-from nerualpha.request.IRequestHeaders import IRequestHeaders
-from nerualpha.request.requestMethods import RequestMethods
 from nerualpha.request.requestParams import RequestParams
 from nerualpha.services.commandService.ICommandService import ICommandService
+from nerualpha.services.config.urlObject import UrlObject
 
 @dataclass
 class CommandService(ICommandService):
@@ -14,10 +13,10 @@ class CommandService(ICommandService):
     def __init__(self,bridge):
         self.bridge = bridge
     
-    async def executeCommand(self,url,data = None,headers = None):
+    async def executeCommand(self,url,method,data = None,headers = None):
         requestParams = RequestParams()
         requestParams.url = url
-        requestParams.method = RequestMethods.POST
+        requestParams.method = method
         if data is not None:
             requestParams.data = data
         
