@@ -26,7 +26,7 @@ class JWT(IJWT):
             return self._token
         
         except Exception as e:
-            raise Exception(f'Error verifying JWT: {e}')
+            raise Exception("Error verifying JWT: " + e)
         
     
     def updateToken(self):
