@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.services.jwt.IJwtPayload import IJwtPayload
+from nerualpha.services.jwt.IJwtPayload import IJwtPayload
 
 @dataclass
 class JWTPayload(IJwtPayload):
