@@ -4,10 +4,8 @@ from abc import ABC, abstractmethod
 
 from nerualpha.IBridge import IBridge
 from nerualpha.providers.logger.ILogContext import ILogContext
-from nerualpha.request.RequestHeaders import RequestHeaders
 from nerualpha.services.commandService.ICommandService import ICommandService
 from nerualpha.services.config.IConfig import IConfig
-from nerualpha.session.CommandHeaders import CommandHeaders
 from nerualpha.session.IActionPayload import IActionPayload
 from nerualpha.session.IFilter import IFilter
 from nerualpha.session.wrappedCallback import WrappedCallback
@@ -38,5 +36,5 @@ class ISession(ABC):
     def constructRequestHeaders(self):
         pass
     @abstractmethod
-    def executeAction(self,actionPayload):
+    def executeAction(self,actionPayload,method):
         pass
