@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IActionPayload import IActionPayload
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.session.IActionPayload import IActionPayload
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 T = TypeVar("T")
 
