@@ -4,14 +4,13 @@ from abc import ABC, abstractmethod
 
 from nerualpha.session.IActionPayload import IActionPayload
 from nerualpha.session.ICommand import ICommand
-from nerualpha.session.ICommandHeaders import ICommandHeaders
 
 T = TypeVar("T")
 
 @dataclass
 class Command(ICommand,Generic[T]):
     actions: List[IActionPayload[T]]
-    header: ICommandHeaders
+    header: Dict[str,str]
     def __init__(self,headers,action):
         self.header = headers
         self.actions = [action]
