@@ -5,17 +5,20 @@ from abc import ABC, abstractmethod
 from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
 from nerualpha.session.IActionPayload import IActionPayload
 from nerualpha.session.ISession import ISession
+from nerualpha.request.requestMethods import RequestMethods
 
 @dataclass
 class RequestInterfaceForCallbacks:
+    method: str
     action: IActionPayload[IPayloadWithCallback]
     session: ISession
-    def __init__(self,session,action):
+    def __init__(self,session,action,method = RequestMethods.POST):
         self.session = session
         self.action = action
+        self.method = method
     
     async def execute(self):
-        await self.session.executeAction(self.action)
+        await self.session.executeAction(self.action,self.method)
         return self.action.payload.callback.id
     
     def reprJSON(self):
