@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IFilter import IFilter
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.session.IFilter import IFilter
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 @dataclass
 class WrappedCallback(IWrappedCallback):
