@@ -2,12 +2,12 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.IUrlPayload import IUrlPayload
 from nerualpha.webhookEvents.messenger.IMessengerAudioEvent import IMessengerAudioEvent
 
 @dataclass
 class MessengerAudioEvent(IMessengerAudioEvent):
-    audio: IUrlObject
+    audio: IUrlPayload
     to: str
     timestamp: str
     message_uuid: str
