@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.IUrlPayload import IUrlPayload
 from nerualpha.webhookEvents.messenger.IMessengerFileEvent import IMessengerFileEvent
 
 @dataclass
@@ -13,7 +13,7 @@ class MessengerFileEvent(IMessengerFileEvent):
     message_type: str
     from_: str
     channel: str
-    file: IUrlObject
+    file: IUrlPayload
     def __init__(self):
         pass
     def reprJSON(self):
