@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.messenger.IMessengerTextEvent import IMessengerTextEvent
+from nerualpha.webhookEvents.messenger.IMessengerTextEvent import IMessengerTextEvent
 
 @dataclass
 class MessengerTextEvent(IMessengerTextEvent):
