@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.mms.IMMSEvent import IMMSEvent
+from nerualpha.webhookEvents.mms.IMMSEvent import IMMSEvent
 
 @dataclass
 class MMSEvent(IMMSEvent):
