@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.sms.ISMSEvent import ISMSEvent
-from src.webhookEvents.sms.ISMSMetadata import ISMSMetadata
-from src.webhookEvents.sms.ISMSUsage import ISMSUsage
+from nerualpha.webhookEvents.sms.ISMSEvent import ISMSEvent
+from nerualpha.webhookEvents.sms.ISMSMetadata import ISMSMetadata
+from nerualpha.webhookEvents.sms.ISMSUsage import ISMSUsage
 
 @dataclass
 class SMSEvent(ISMSEvent):
