@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.sms.ISMSUsage import ISMSUsage
+from nerualpha.webhookEvents.sms.ISMSUsage import ISMSUsage
 
 @dataclass
 class SMSUsage(ISMSUsage):
