@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.IBaseEvent import IBaseEvent
-from src.webhookEvents.whatsapp.IProfileName import IProfileName
-from src.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
+from nerualpha.webhookEvents.IBaseEvent import IBaseEvent
+from nerualpha.webhookEvents.whatsapp.IProfileName import IProfileName
+from nerualpha.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
 
 
 #interface
