@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.whatsapp.IProfileName import IProfileName
+from nerualpha.webhookEvents.whatsapp.IProfileName import IProfileName
 
 @dataclass
 class ProfileName(IProfileName):
