@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.IUrlPayload import IUrlPayload
 from nerualpha.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
 from nerualpha.webhookEvents.whatsapp.IProfileName import IProfileName
 from nerualpha.webhookEvents.whatsapp.IWhatsappImageEvent import IWhatsappImageEvent
@@ -15,7 +15,7 @@ class WhatsappImageEvent(IWhatsappImageEvent):
     from_: str
     channel: str
     message_type: str
-    image: IUrlObject
+    image: IUrlPayload
     profile: IProfileName = None
     context: IMessageEventContext = None
     provider_message: str = None
